@@ -94,6 +94,7 @@ func matchTemplate(url, template string) string {
 			matcher := regexp.MustCompile(templateVarRegex.ReplaceAllString(tplPart, ".*"))
 			if matcher.MatchString(urlPart) && urlPart != "" {
 				tplParts[i] = urlPart
+				continue
 			}
 		} else if urlPart == tplPart {
 			// This is an exact path match.
@@ -269,6 +270,7 @@ func Init(name string, version string) {
 	head := &cobra.Command{
 		GroupID:           "generic",
 		Use:               "head uri",
+		Aliases:           []string{"HEAD"},
 		Short:             "Head a URI",
 		Long:              "Perform an HTTP HEAD on the given URI",
 		Args:              cobra.MinimumNArgs(1),
@@ -282,6 +284,7 @@ func Init(name string, version string) {
 	options := &cobra.Command{
 		GroupID:           "generic",
 		Use:               "options uri",
+		Aliases:           []string{"OPTIONS"},
 		Short:             "Options a URI",
 		Long:              "Perform an HTTP OPTIONS on the given URI",
 		Args:              cobra.MinimumNArgs(1),
@@ -295,6 +298,7 @@ func Init(name string, version string) {
 	get := &cobra.Command{
 		GroupID:           "generic",
 		Use:               "get uri",
+		Aliases:           []string{"GET"},
 		Short:             "Get a URI",
 		Long:              "Perform an HTTP GET on the given URI",
 		Args:              cobra.MinimumNArgs(1),
@@ -308,6 +312,7 @@ func Init(name string, version string) {
 	post := &cobra.Command{
 		GroupID:           "generic",
 		Use:               "post uri [body...]",
+		Aliases:           []string{"POST"},
 		Short:             "Post a URI",
 		Long:              "Perform an HTTP POST on the given URI",
 		Args:              cobra.MinimumNArgs(1),
@@ -321,6 +326,7 @@ func Init(name string, version string) {
 	put := &cobra.Command{
 		GroupID:           "generic",
 		Use:               "put uri [body...]",
+		Aliases:           []string{"PUT"},
 		Short:             "Put a URI",
 		Long:              "Perform an HTTP PUT on the given URI",
 		Args:              cobra.MinimumNArgs(1),
@@ -334,6 +340,7 @@ func Init(name string, version string) {
 	patch := &cobra.Command{
 		GroupID:           "generic",
 		Use:               "patch uri [body...]",
+		Aliases:           []string{"PATCH"},
 		Short:             "Patch a URI",
 		Long:              "Perform an HTTP PATCH on the given URI",
 		Args:              cobra.MinimumNArgs(1),
@@ -347,6 +354,7 @@ func Init(name string, version string) {
 	delete := &cobra.Command{
 		GroupID:           "generic",
 		Use:               "delete uri [body...]",
+		Aliases:           []string{"DELETE"},
 		Short:             "Delete a URI",
 		Long:              "Perform an HTTP DELETE on the given URI",
 		Args:              cobra.MinimumNArgs(1),
@@ -544,6 +552,7 @@ Not after (expires): %s (%s)
 	AddGlobalFlag("rsh-client-cert", "", "Path to a PEM encoded client certificate", "", false)
 	AddGlobalFlag("rsh-client-key", "", "Path to a PEM encoded private key", "", false)
 	AddGlobalFlag("rsh-ca-cert", "", "Path to a PEM encoded CA cert", "", false)
+	AddGlobalFlag("rsh-ignore-status-code", "", "Do not set exit code from HTTP status code", false, false)
 
 	Root.RegisterFlagCompletionFunc("rsh-output-format", func(cmd *cobra.Command, args []string, toComplete string) ([]string, cobra.ShellCompDirective) {
 		return []string{"auto", "json", "yaml"}, cobra.ShellCompDirectiveNoFileComp
@@ -674,7 +683,7 @@ func Defaults() {
 }
 
 // Run the CLI! Parse arguments, make requests, print responses.
-func Run() error {
+func Run() (returnErr error) {
 	// We need to register new commands at runtime based on the selected API
 	// so that we don't have to potentially refresh and parse every single
 	// registered API just to run. So this is a little hacky, but we hijack
@@ -720,13 +729,14 @@ func Run() error {
 	if caCert, _ := GlobalFlags.GetString("rsh-ca-cert"); caCert != "" {
 		viper.Set("rsh-ca-cert", caCert)
 	}
-	if query, _ := GlobalFlags.GetStringSlice("rsh-query"); len(query) > 0 {
+	if query, _ := GlobalFlags.GetStringArray("rsh-query"); len(query) > 0 {
 		viper.Set("rsh-query", query)
 	}
-	if headers, _ := GlobalFlags.GetStringSlice("rsh-header"); len(headers) > 0 {
+	if headers, _ := GlobalFlags.GetStringArray("rsh-header"); len(headers) > 0 {
 		viper.Set("rsh-header", headers)
 	}
 	profile, _ := GlobalFlags.GetString("rsh-profile")
+	viper.Set("rsh-profile", profile)
 
 	// Now that global flags are parsed we can enable verbose mode if requested.
 	if viper.GetBool("rsh-verbose") {
@@ -749,6 +759,11 @@ func Run() error {
 			// there is no need to do anything since the normal flow will catch
 			// the command being missing and print help.
 			if cfg, ok := configs[apiName]; ok {
+
+				// This is used to give context to findApi
+				// Smallest fix for https://github.com/danielgtaylor/restish/issues/128
+				viper.Set("api-name", apiName)
+
 				currentConfig = cfg
 				for _, cmd := range Root.Commands() {
 					if cmd.Use == apiName {
@@ -775,7 +790,7 @@ func Run() error {
 		if !loaded {
 			// This could be a URL or short-name as part of a URL for generic
 			// commands. We should load the config for shell completion.
-			if apiName == "head" || apiName == "options" || apiName == "get" || apiName == "post" || apiName == "put" || apiName == "patch" || apiName == "delete" && len(args) > 2 {
+			if (apiName == "head" || apiName == "options" || apiName == "get" || apiName == "post" || apiName == "put" || apiName == "patch" || apiName == "delete") && len(args) > 2 {
 				apiName = args[2]
 			}
 			apiName = fixAddress(apiName)
@@ -785,8 +800,6 @@ func Run() error {
 		}
 	}
 
-	var returnErr error
-
 	// Phew, we made it. Execute the command now that everything is loaded
 	// and all the relevant sub-commands are registered.
 	defer func() {
@@ -795,6 +808,8 @@ func Run() error {
 			LogDebug("%s", string(debug.Stack()))
 			if e, ok := err.(error); ok {
 				returnErr = e
+			} else {
+				returnErr = fmt.Errorf("%v", err)
 			}
 		}
 	}()
@@ -805,3 +820,12 @@ func Run() error {
 
 	return returnErr
 }
+
+// GetExitCode returns the exit code to use based on the last HTTP status code.
+func GetExitCode() int {
+	if s := GetLastStatus() / 100; s > 2 && !viper.GetBool("rsh-ignore-status-code") {
+		return s
+	}
+
+	return 0
+}
